<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Elementor hostiko-tld-table-Widget.
 *
 * Elementor widget that uses the hostiko-tld-table control.
 *
 * @since 1.0.0
 */
class Elementor_Hostiko_Tld_Table_Widget extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve hostiko-tld-table widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'hostiko-tld-table';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve hostiko-tld-table widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Hostiko Data Table', 'elementor-hostiko-tld-table-control' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve hostiko-tld-table widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-carousel-loop';
	}

	/**
	 * Register hostiko-tld-table widget controls.
	 *
	 * Add input fields to allow the user to customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'elementor-hostiko-tld-table-control' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
			'hostiko_tld_heading', [
				'label' => __( 'TLD Heading', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'TLDs' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
       
        $this->add_control(
			'hostiko_years_heading', [
				'label' => __( 'Years heading', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Years' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
        $this->add_control(
			'hostiko_register_domain_heading', [
				'label' => __( 'Register Heading', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Register' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
        $this->add_control(
			'hostiko_transfer_domain_heading', [
				'label' => __( 'Transfer Heading', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Transfer' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
        $this->add_control(
			'hostiko_renew_domain_heading', [
				'label' => __( 'Renew Heading', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( 'Renew' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);

		$repeater = new \Elementor\Repeater();
    
        $repeater->add_control(
			'hostiko_tld_name', [
				'label' => __( 'TLD Name', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '.com' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
        $repeater->add_control(
			'hostiko_tld_currency', [
				'label' => __( 'Currency', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '$' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
        $repeater->add_control(
			'hostiko_no_years', [
				'label' => __( 'Years', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '2 Years' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
        $repeater->add_control(
			'hostiko_register_domain', [
				'label' => __( 'Register', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '12.00' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
        $repeater->add_control(
			'hostiko_transfer_domain', [
				'label' => __( 'Transfer', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '12.00' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
        $repeater->add_control(
			'hostiko_renew_domain', [
				'label' => __( 'Renew', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => __( '12.00' , 'elementor-hostiko-tld-table-control' ),
				'label_block' => true,
			]
		);
        
		$this->add_control(
			'list',
			[
				'label' => __( 'Repeater List', 'elementor-hostiko-tld-table-control' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'hostiko_tld_name' => __( 'TLD Name', 'elementor-hostiko-tld-table-control' ),
						'hostiko_tld_currency' => __( 'Currency', 'elementor-hostiko-tld-table-control' ),
						'hostiko_no_years' => __( 'Years', 'elementor-hostiko-tld-table-control' ),
						'hostiko_register_domain' => __( 'Register', 'elementor-hostiko-tld-table-control' ),
						'hostiko_transfer_domain' => __( 'Transfer', 'elementor-hostiko-tld-table-control' ),
						'hostiko_renew_domain' => __( 'Renew', 'elementor-hostiko-tld-table-control' ),
					],
					[
						'hostiko_tld_name' => __( 'TLD Name', 'elementor-hostiko-tld-table-control' ),
						'hostiko_tld_currency' => __( 'Currency', 'elementor-hostiko-tld-table-control' ),
						'hostiko_no_years' => __( 'Years', 'elementor-hostiko-tld-table-control' ),
						'hostiko_register_domain' => __( 'Register', 'elementor-hostiko-tld-table-control' ),
						'hostiko_transfer_domain' => __( 'Transfer', 'elementor-hostiko-tld-table-control' ),
						'hostiko_renew_domain' => __( 'Renew', 'elementor-hostiko-tld-table-control' ),
					],
				],
				'heading_field' => '{{{ list_heading }}}',
			]
		);
		
        $this->end_controls_section();

		
		
		////////////////////////////////////////////////  Container Style Start /////////////////////////////////////////////////
		$this->start_controls_section(
			'conatiner_tld_style_section',
			[
				'label' => esc_html__( 'Container Style', 'textdomain' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
       
		
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'conatiner_tld_background',
				'label' => __( 'Background', 'textdomain' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .hostiko-tld-table-section .hostiko-tld-table',
            ]
        );  
		
		$this->add_responsive_control(
			'conatiner_tld_border_radius',
			[
				'label' => __( 'Conatiner Border Radius', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .hostiko-tld-table-section .hostiko-tld-table' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					
				],
				
			]
		);
		$this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'conatiner_tld_border',
                'label' => __( 'Border', 'textdomain' ),
                'selector' => '{{WRAPPER}} .hostiko-tld-table-section .hostiko-tld-table',
            ]
        );
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'conatiner_tld_box_shadow',
				'selector' => '{{WRAPPER}} .hostiko-tld-table-section .hostiko-tld-table',
			]
		);

        $this->end_controls_section(); 
		////////////////////////////////////////////////  Conatiner Style Ends ///////////////////////////////////////////////
		////////////////////////////////////////////////  Header Style Start /////////////////////////////////////////////////
		$this->start_controls_section(
			'header_style_section',
			[
				'label' => esc_html__( 'Header Style', 'textdomain' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'header_typography',
				'label' => __( 'Typography', 'textdomain' ),
				'selector' => '{{WRAPPER}} .hostiko-tld-table tr th',
			]
		);
        $this->add_control(
            'header_color',
            [
                'label' => esc_html__('Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hostiko-tld-table tr th' => 'color: {{VALUE}}',
                ],
            ]
        );
		$this->add_responsive_control(
			'header_padding',
			[
				'label' => __( 'Padding', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .hostiko-tld-table tr th' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		); 
		$this->add_control(
            'header_alignment',
            [
                'label' => esc_html__('Alignment', 'textdomain'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'textdomain'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'textdomain'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'textdomain'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .hostiko-tld-table tr th' => 'text-align: {{VALUE}};',
                ],
            ]
        );
		$this->add_group_control(
            \Elementor\Group_Control_Border::get_type(),
            [
                'name' => 'header_border',
                'label' => __( 'Border', 'textdomain' ),
                'selector' => '{{WRAPPER}} .hostiko-tld-table-section .hostiko-tld-table tr th',
            ]
        );
        
		$this->add_responsive_control(
			'header_borderbox_radius',
			[
				'label' => esc_html__( 'Border Radius', 'elementor' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'px', '%', 'em', 'rem', 'vw', 'custom' ],
				'default' => [
					'size' => 15,
				],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .hostiko-tld-table .hostiko-tld-header-row .tld_heading' => 'border-top-left-radius: {{SIZE}}{{UNIT}}',
					'{{WRAPPER}} .hostiko-tld-table .hostiko-tld-header-row th:first-child' => 'border-bottom-left-radius: {{SIZE}}{{UNIT}}',
					'{{WRAPPER}} .hostiko-tld-table .hostiko-tld-header-row .renew_domain_heading' => 'border-bottom-right-radius: {{SIZE}}{{UNIT}}',
					'{{WRAPPER}} .hostiko-tld-table .hostiko-tld-header-row th:last-child' => 'border-top-right-radius: {{SIZE}}{{UNIT}}',
				],
					
			]
		);
			
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'header_background',
				'label' => __( 'Background', 'textdomain' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .hostiko-tld-table tr th',
            ]
        );  
		
		$this->add_responsive_control(
			'tld_container_border_radius',
			[
				'label' => __( 'Conatiner Border Radius', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .hostiko-tld-table' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
					
				],
				
			]
		);
        $this->end_controls_section(); 
		////////////////////////////////////////////////  Header Style Ends /////////////////////////////////////////////////
		////////////////////////////////////////////////  Content Style Ends ///////////////////////////////////////////////// 
        $this->start_controls_section(
			'content_style_section',
			[
				'label' => esc_html__( 'Content Style', 'textdomain' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'content_typography',
				'label' => __( 'Typography', 'textdomain' ),
				'selector' => '{{WRAPPER}} .hostiko-tld-table tr td',
			]
		);
        $this->add_control(
            'content_color',
            [
                'label' => esc_html__('Color', 'textdomain'),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .hostiko-tld-table tr td' => 'color: {{VALUE}}',
                ],
            ]
        );
        
		$this->add_responsive_control(
			'content_padding',
			[
				'label' => __( 'Padding', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .hostiko-tld-table tr td' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'content_background-even',
				'label' => __( 'Background Even', 'textdomain' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .hostiko-tld-table tr:nth-child(even)',
            ]
        );  
        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(),
            [
                'name' => 'content_background-odd',
				'label' => __( 'Background Odd', 'textdomain' ),
                'types' => [ 'classic', 'gradient', 'video' ],
                'selector' => '{{WRAPPER}} .hostiko-tld-table tr:nth-child(odd)',
            ]
        );  
		$this->add_control(
            'content_header_alignment',
            [
                'label' => esc_html__('Alignment', 'textdomain'),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'textdomain'),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'textdomain'),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'textdomain'),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'left',
                'selectors' => [
                    '{{WRAPPER}} .hostiko-tld-table tr td' => 'text-align: {{VALUE}};',
                ],
            ]
        );
		$this->end_controls_section();
        /////////////////////////////////////////////////////////////////////////////////////////////////////////////////
        

	}


	/**
	 * Render hostiko-tld-table widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
				?>
				<div class="hostiko-tld-table-section position-relative">
					<div class="position-relative" data-aos="fade-up">
                        <table class="hostiko-tld-table">
                            <thead class="hostiko-tld-header bg_gradient">
                                <tr class="hostiko-tld-header-row">
                                    <th class="tld_heading"><?php echo $settings['hostiko_tld_heading'] ?></th>
                                    <th class="years_heading"><?php echo $settings['hostiko_years_heading'] ?></th>
                                    <th class="register_domain_heading"><?php echo $settings['hostiko_register_domain_heading'] ?></th>
                                    <th class="transfer_domain_heading"><?php echo $settings['hostiko_transfer_domain_heading'] ?></th>
                                    <th class="renew_domain_heading"><?php echo $settings['hostiko_renew_domain_heading'] ?></th>
                                </tr>
                            </thead>
                            <tbody> 
                                <?php
                                    $count = 0;
                                    if ( $settings['list'] ) {
                                    foreach ( $settings['list'] as $item ) {	
                                ?>
                                    <tr class="hostiko-tld-body-row">
                                        <td data-label="<? echo $settings['hostiko_tld_heading'] ?>"><?php echo $item['hostiko_tld_name'] ?></td>
                                        <td data-label="<? echo $settings['hostiko_years_heading'] ?>"><?php echo $item['hostiko_no_years'] ?></td>
                                        <td data-label="<? echo $settings['hostiko_register_domain_heading'] ?>"><?php echo $item['hostiko_tld_currency'].$item['hostiko_register_domain'] ?></td>
                                        <td data-label="<? echo $settings['hostiko_transfer_domain_heading'] ?>"><?php echo $item['hostiko_tld_currency'].$item['hostiko_transfer_domain'] ?></td>
                                        <td data-label="<? echo $settings['hostiko_renew_domain_heading'] ?>"><?php echo $item['hostiko_tld_currency'].$item['hostiko_renew_domain'] ?></td>
                                    </tr>
                                    <?php
                                        $count++;
                                    }
                                    }
                                    ?>
                            </tbody>
                        </table>
                        
					</div>
				</div> 
				
				
			<?php
				
	}
	

}
