(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	 $(document).ready(function(){
		themeActivationContent();
		envatoPurchaseCodeValidation();
		minorJsCode();
		changeCodestarTabContent();
		disconnectDomain();
		installChildTheme();
		downloadThemeFiles();
		downloadImportFiles();
		akdSyncWhmcs();

		$('.csf-tabbed-nav')[0].children[3].style.display = 'none';
	});

	function akdSyncWhmcs(){

		$('input[name="akd-framework-admin-page[akd-whmcs-api-identifier]"]').attr('type', 'password');
		$('input[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').attr('type', 'password');
		$('input[name="akd-framework-admin-page[akd-whmcs-api-identifier]"]').val(akd_localization_data.whmcs_identifier ? akd_localization_data.whmcs_identifier : '');
		$('input[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').val(akd_localization_data.whmcs_secret ? akd_localization_data.whmcs_secret : '');

		if(akd_localization_data.whmcs_url && akd_localization_data.whmcs_identifier){
			$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="csf-field"> <button type="button" class="button-primary sync_whmcs" id="re_sync_whmcs" value="re_sync_whmcs">Re-Sync WHMCS</button> </div>');
		} else {
			$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="csf-field"> <button type="button" class="button-primary sync_whmcs" id="sync_whmcs" value="sync_whmcs">Sync WHMCS</button> </div>');
		}
		
		$(document).on('click', '#sync_whmcs', function(){

			let content = `
				<div class="akd-wrapper">
					<div class="akd-loader-container">
					<div class="akd-loader"></div>
					</div>
				</div>
			`;
			$('.csf-options').append(content);

			let whm_url = $('[name="akd-framework-admin-page[akd-whmcs-api]"]').val();
			let whm_secret = $('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').val();
			let whm_identifier = $('[name="akd-framework-admin-page[akd-whmcs-api-identifier]"]').val();
			if(whm_url != '' && whm_secret != '' && whm_identifier != ''){
				$.ajax({
					type: "POST",
					url: akd_localization_data.urls_to_frontend.ajaxUrl,
					data: {
						action: 'checkCurl',
						url: whm_url,
					},
					success: function(res) {
						let curl_data = JSON.parse(res);
						if(curl_data.type == 'success'){
							$.ajax({
								url: akd_localization_data.urls_to_frontend.ajaxUrl,
								type: "POST",
								data: {
									action: 'getGroups',
									url: whm_url,
									secret: whm_secret,
									identifier: whm_identifier,
								},
								success: function (res) {

									let data = JSON.parse(res);
									console.log(data);
									if (data.type == 'success') {
										$('.akd-wrapper').remove();
										$('.validate-error').remove();
										$('.validate-success').remove();
										$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="validate-success"> '+data.msg+' </div>')
										setTimeout(function(){
											$('.csf-top-save').click();
										}, 3000);
									} else if (data.type == 'error') {
										$('.akd-wrapper').remove();
										$('.validate-error').remove();
										$('.validate-success').remove();
										$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="validate-error"> '+data.msg+' </div>')
									}
								},
								error: function (xhr, status, error) {
									$('.akd-wrapper').remove();
									console.log("Error:", error);
								}
							});
							$.ajax({
								url: akd_localization_data.urls_to_frontend.ajaxUrl,
								type: "POST",
								data: {
									action: 'getTLDs',
									url: whm_url,
									secret: whm_secret,
									identifier: whm_identifier,
								},
								success: function (res) {
									let data = JSON.parse(res);
									console.log(data);
									
								},
								error: function (xhr, status, error) {
									console.log("Error:", error);
								}
							});
						}
						else if (curl_data.type == 'error') {
							$('.akd-wrapper').remove();
							$('.validate-error').remove();
							$('.validate-success').remove();
							$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="validate-error"> '+curl_data.msg+' </div>')
						}
					},
					error: function(res){
						console.log(res);
					}
				});
			} else {
				$('.akd-wrapper').remove();
				$('.validate-error').remove();
				$('.validate-success').remove();
				$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="validate-error"> Some Fields can not be empty!!! </div>')
			}

		});

		$(document).on('click', '#re_sync_whmcs', function(){
			
			let content = `
				<div class="akd-wrapper">
					<div class="akd-loader-container">
					<div class="akd-loader"></div>
					</div>
				</div>
			`;
			$('.csf-options').append(content);
	
			let whm_url = $('[name="akd-framework-admin-page[akd-whmcs-api]"]').val();
			let whm_secret = $('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').val();
			let whm_identifier = $('[name="akd-framework-admin-page[akd-whmcs-api-identifier]"]').val();
			if(whm_url != '' && whm_secret != '' && whm_identifier != ''){
			   
				$.ajax({
					type: "POST",
					url: akd_localization_data.urls_to_frontend.ajaxUrl,
					data: {
						action: 'checkCurl',
						url: whm_url,
					},
					success: function(res) {
						let curl_data = JSON.parse(res);
						if(curl_data.type == 'success'){
							$.ajax({
								url: akd_localization_data.urls_to_frontend.ajaxUrl,
								type: "POST",
								data: {
									action: 'getGroups_resync',
									url: whm_url,
									secret: whm_secret,
									identifier: whm_identifier,
								},
								success: function (res) {
	
									let data = JSON.parse(res);
									console.log(data);
									if (data.type == 'success') {
										$('.akd-wrapper').remove();
										$('.validate-error').remove();
										$('.validate-success').remove();
										$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="validate-success"> '+data.msg+' </div>')
										setTimeout(function(){
											$('.csf-top-save').click();
										}, 3000);
									} else if (data.type == 'error') {
										$('.akd-wrapper').remove();
										$('.validate-error').remove();
										$('.validate-success').remove();
										$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="validate-error"> '+data.msg+' </div>')
									}
								},
								error: function (xhr, status, error) {
									$('.akd-wrapper').remove();
									console.log("Error:", error);
								}
							});
							
						}
						else if (curl_data.type == 'error') {
							$('.akd-wrapper').remove();
							$('.validate-error').remove();
							$('.validate-success').remove();
							$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="validate-error"> '+curl_data.msg+' </div>')
						}
					},
					error: function(res){
						console.log(res);
					}
				});
				
			}
			else{
				$('.akd-wrapper').remove();
				$('.validate-error').remove();
				$('.validate-success').remove();
				$('[name="akd-framework-admin-page[akd-whmcs-api-secret]"]').parent().parent().after('<div class="validate-error"> Some Fields can not be empty!!! </div>')
			}
			
		});
	}

	//method to disconnect domain
	function disconnectDomain(){
		$(document).on('click', '.akd-disconnect-domain', function(e){
			e.preventDefault();

			if($(this).data('purchase-code')){
				sessionStorage.removeItem('activeTab');

				let data = {
					action: 'disconnect_domain',
					'purchaseCode' : $(this).data('purchase-code') ? $(this).data('purchase-code') : '',
				}
	
				whmcsAjaxCall(data, $(this));
			}
		});
	}

	//method to add additoinal HTML content for the theme activatation screen
	function themeActivationContent(){
		// Cache the jQuery selectors
		let radioButtons = $('input[name="akd-framework-admin-page[akd-theme-dashboard][akd-act-options]"]');
		let ulParent = radioButtons.closest('ul');
		
		// Function to create custom HTML based on the selected radio button
		function createCustomHTML(activationMethod) {
			let akdActivationHtml = '';
			if (activationMethod === 'purchase-code') {
				akdActivationHtml = `<li class="akd-act-field">
						<label>
							<span class="akd-purchase-code akd-label">Envato Purchase code <sup class="required">*</sup></span>
							<input type="password" name="akd_theme_purchase_code" placeholder="Envato Purchase code (required)" />
							<div class="akd-notice-container">
								<div class="akd-notice-box">
									Need help locating your purchase code? <a href="https://help.market.envato.com/hc/en-us/articles/202822600-Where-Is-My-Purchase-Code-" target="_blank">Use this guide.</a>
								</div>
							</div>
							<input type="button" class="akd-validate-envato-code button-primary" value="Validate Purchase Code">
							<div style="color:red" class="loader">Loading...</div>
						</label>
				</li>`;
			} else if (activationMethod === 'get-purchase-code') {
				akdActivationHtml = `<li class="akd-act-field">
					<label>
						<span class="akd-purchase-code akd-label">Envato Elements Token <sup class="required">*</sup></span>
						<input type="text" name="akd_theme_purchase_code" placeholder="Envato Purchase Code (required)">
						<div class="akd-notice-container">
							<div class="akd-notice-box">
								<a href="#" target="_blank">Nevigate to this link</a> to generate Envato Elements Token to activate your Hostiko theme.
							</div>
						</div>
						<input type="button" class="akd-validate-envato-code button-primary" value="Validate Purchase Code">
						<div style="color:red" class="loader">Loading...</div>
					</label>
				</li>`;
			}

			$('.validate-error').remove();
			$('.validate-success').remove();
			return akdActivationHtml;
		}
		
		// Function to append custom HTML to the UL
		function appendCustomHTML(html) {
			ulParent.append(html);
		}
		
		// On page load
		let initialActivationMethod = radioButtons.filter(':checked').val();
		appendCustomHTML(createCustomHTML(initialActivationMethod));
		
		// On change
		radioButtons.change(function() {
			// Remove existing custom HTML
			$('.akd-act-field').remove();
			
			// Create and append new custom HTML based on the selected radio button
			let akdActivationMethod = $(this).val();
			appendCustomHTML(createCustomHTML(akdActivationMethod));
		});
	}

	//method to validate envato purchase code
    function envatoPurchaseCodeValidation(){
        //send ajax request
        $(document).on('click', '.akd-validate-envato-code', function(){
			$('.loader').show();
			let emailPattern = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
			if($('[name="akd-framework-admin-page[akd-theme-dashboard][akd-act-name]"]').val() != '' && $('[name="akd-framework-admin-page[akd-theme-dashboard][akd-act-email]"]').val() != ''){
				if($('[name="akd_theme_purchase_code"]').val() != '' && emailPattern.test($('[name="akd-framework-admin-page[akd-theme-dashboard][akd-act-email]"]').val())){
					let data = {
						action: 'validate_purchase_code',
						'purchaseCode' : $('[name="akd_theme_purchase_code"]').val() ? $('[name="akd_theme_purchase_code"]').val() : '',
						'name' : $('[name="akd-framework-admin-page[akd-theme-dashboard][akd-act-name]"]').val() ? $('[name="akd-framework-admin-page[akd-theme-dashboard][akd-act-name]"]').val() : '',
						'email' : $('[name="akd-framework-admin-page[akd-theme-dashboard][akd-act-email]"]').val() ? $('[name="akd-framework-admin-page[akd-theme-dashboard][akd-act-email]"]').val() : '',
					}
	
					whmcsAjaxCall(data, $(this));
				} else if(!emailPattern.test($('[name="akd-framework-admin-page[akd-theme-dashboard][akd-act-email]"]').val())){
					$('.loader').hide();
					$('.validate-error').remove();
					$(this).parent().parent().after('<div class="validate-error"> Please enter valid email address. </div>')
				} else {
					$('.loader').hide();
					$('.validate-error').remove();
					$(this).parent().parent().after('<div class="validate-error"> Please add your purchase code first. </div>')
				}
			} else {
				$('.loader').hide();
				$('.validate-error').remove();
				$(this).parent().parent().after('<div class="validate-error"> Name and email is required. </div>')
			}
        });
    }

	//method to trigger ajax call
    function whmcsAjaxCall(data, currentElement){
        $.ajax({
            type: 'POST',
            url: akd_localization_data.urls_to_frontend.ajaxUrl,
            data: data,
            success: function(response) {
                if(response.success === true && response.data != undefined){
					$('.loader').hide();
                    $('.validate-success').remove();
                    $('.validate-error').remove();
                    currentElement.parent().parent().after('<div class="validate-success"> '+response.data.message+' </div>')
                    setTimeout(function(){
                        $('.csf-top-save').click();
                    }, 4000);
                } else if(response.success === false && response.data != undefined){
					$('.loader').hide();
                    $('.validate-error').remove();
					$('.validate-success').remove();
                    currentElement.parent().parent().after('<div class="validate-error"> '+response.data.message+' </div>')
                }
            },
            error: function(error) {
                return error
            }
        });
    }

	//method to change tab content based on active tab
    function changeCodestarTabContent() {
		$(document).on('click', '.csf-tabbed-nav', function(){
			let content = '';
			if($(this).find('.csf-tabbed-active').text() === 'Plugins'){
				//if theme is not activated then show alert in the plugins tab
				if(!akd_localization_data.additional_data.purchaseCode){
					content += `
						<div class="csf-field csf-plugins">
							<div class="plugin-container">
								<p> Activate your theme in order to be able to install additional plugins. </p>
							</div>
						</div>
					`;
					// Show relevant data to the active tab
					showRelevantDataToTab($(this), content);
				} else {
					sessionStorage.setItem('activeTab', 'Plugins');
				}
			} else if($(this).find('.csf-tabbed-active').text() === 'Demo Data'){
				//if theme is not activated then show alert within the Demo Data tab
				if(!akd_localization_data.additional_data.purchaseCode){
					content += `
						<div class="csf-field csf-demo-data">
							<div class="demo-data-container">
								<p> Activate your theme in order to be able to install demo data. </p>
							</div>
						</div>
					`;
					// Show relevant data to the active tab
					showRelevantDataToTab($(this), content);
				} else {
					sessionStorage.setItem('activeTab', 'Demo Data');
				}
			} else if($(this).find('.csf-tabbed-active').text() === 'Theme Setup'){
				//if theme is not activated then show alert within the Theme Setup tab
				if(!akd_localization_data.additional_data.purchaseCode){
					content += `
						<div class="csf-field csf-demo-data">
							<div class="demo-data-container">
								<p> Activate your theme in order to be able to steup your theme. </p>
							</div>
						</div>
					`;
					// Show relevant data to the active tab
					showRelevantDataToTab($(this), content);
				} else {
					sessionStorage.setItem('activeTab', 'Theme Setup');
				}
			} else if($(this).find('.csf-tabbed-active').text() === 'Theme Settings'){
				//if theme is not activated then show alert within the Theme Setup tab
				if(!akd_localization_data.theme_info.elementor){
					content += `
						<div class="csf-field csf-demo-data">
							<div class="demo-data-container">
								<p> Please activate your theme and install required plugins. </p>
							</div>
						</div>
					`;
					// Show relevant data to the active tab
					showRelevantDataToTab($(this), content);
				} else {
					sessionStorage.setItem('activeTab', 'Theme Settings');
				}
			}
		});
    }

	//method to show custom data to the codestar tab
    function showRelevantDataToTab(currentElement, content) {
        // Iterate over each tabbed content div
        currentElement.next().find('.csf-tabbed-content').each(function(index, div) {
            // Check if the div is not hidden
            if (!$(div).hasClass('hidden')) {
                // Set innerHTML of the div to the provided content
                div.innerHTML = content;
            }
        });
    }

	//method to manage minor JS code events
	function minorJsCode(){

		if (window.location.href.indexOf("akd-framework") > -1 && sessionStorage.getItem('activeTab')) {
			setTimeout(function(){
				// Retrieve the active tab from sessionStorage
				var activeTab = sessionStorage.getItem('activeTab');
	
				// Remove the 'csf-tabbed-active' class from all anchor elements
				$('.csf-tabbed-nav a').removeClass('csf-tabbed-active');
			
				// Initialize a variable to store the index
				var activeTabIndex = -1;

				if(sessionStorage.getItem('activeTab') === 'Install Demo'){
					$('.csf-tabbed-nav')[0].children[3].style.display = 'block';
					$('.csf-tabbed-active').next().click();
					$('.js-merlin-demo-import-select').attr('disabled', true);
			
					// Show the import section and hide the trigger button
					$('.akd-demo-import').css('display', 'flex');
					// $('.akd-trigger-import').hide();
					$('.akd-demo-import-content').show();

					let layoutNumber = sessionStorage.getItem('layoutNumber');

					if($('.merlin__select-control.js-merlin-demo-import-select').length <= 0){

						let content = `
							<select class="merlin__select-control js-merlin-demo-import-select" disabled="disabled">
								<option value="0">Hostiko Layout ${layoutNumber}</option>
							</select>
						`;
						$('.akd-demo-import .merlin__content--transition').append(content);
					} else {
						// Get the dropdown element
						let selectDropdown = $('.merlin__select-control.js-merlin-demo-import-select');
									
						// Loop through each option to find the one with matching text
						selectDropdown.find('option').each(function(index, option) {
							if ($(option).text().includes(layoutNumber)) {
								// If the option text contains the layout number, set it as selected
								selectDropdown.val($(option).val());
								// Break out of the loop since we found the matching option
								return false;
							}
						});
					}
				}
			
				// Add the 'csf-tabbed-active' class to the anchor element corresponding to the activeTab
				$('.csf-tabbed-nav a').each(function(index) {
					if ($(this).text().trim() === activeTab) {
						$(this).addClass('csf-tabbed-active');
						activeTabIndex = index; // Set the activeTabIndex
					}
				});

				// $('.csf-tabbed-active').click();
				// activeTabIndex now contains the index of the anchor element with the 'csf-tabbed-active' class
			
				// Loop through each tab content
				$('.csf-tabbed-content').each(function(index) {
					// If the index matches the activeTabIndex, remove the 'hidden' class
					if (index === activeTabIndex) {
						$(this).removeClass('hidden');
					} else {
						// Otherwise, add the 'hidden' class
						$(this).addClass('hidden');
					}
				});
	
			}, 1800);
		} else {
			sessionStorage.removeItem('activeTab');
		}
		
		//all time load plugin listing of merlin framework
		$('body').addClass('merlin__drawer--open');

		//update theme activatation status on the framework
		if($('.csf-options').data('unique') === 'akd-framework-admin-page'){
			$('<p class="akd-theme-status"> Not Activated </p>').insertBefore('.csf-header-left');
			if(akd_localization_data.additional_data.purchaseCode){
				$('[name="akd_theme_purchase_code"]').val(akd_localization_data.additional_data.purchaseCode);
				$('.akd-theme-status').css('background-color', 'green');
				$('.akd-theme-status').text('Activated')
			}
		}

		let generalTabIntroContent = `
			<div class="akd-general-tab-content">
				<h2 class="akd-general-into-title">
					Welcome ${akd_localization_data.theme_info.themeName} Customers					
				</h2>
				<div class="akd-general-section-description">
					<p>Get started with Hostiko! To access plugins, demo content, support, and updates, please activate your theme.</p>
				</div>
			</div>
		`;
		$(generalTabIntroContent).insertBefore('.akd-full-name');
		
		//if theme is activated then show welcome content on the general tab
		if($('.csf-tabbed-nav').find('.csf-tabbed-active').text() === 'General'){
			if(akd_localization_data.additional_data.purchaseCode){
				let content = generalTabContentAfterActivation();
				// Show relevant data to the active tab
				showRelevantDataToTab($('.csf-tabbed-nav'), content);
			} else {
				$('.csf-tabbed-content .akd-general-tab-content').css('display', 'block');
				$('.csf-tabbed-content .akd-full-name').css('display', 'block');
				$('.csf-tabbed-content .akd-email').css('display', 'block');
				$('.csf-tabbed-content .akd-act-option').css('display', 'block');
			}
		}

		//proceed to next step
		$(document).on('click', '.akd-cdf-next-step, .akd-after-req-plugin-inst, .akd-req-plugin-next', function(e){
			e.preventDefault();
			$('.csf-tabbed-active').next().click();
		});

		$(document).on('click', '.akd-content-next', function(e){
			e.preventDefault();
			$('.csf-tabbed-active').next().next().click();
		});

		//view site after demo import
		$(document).on('click', '.akd-view-site', function(e){
			e.preventDefault();
			window.open(akd_localization_data.urls_to_frontend.siteUrl, '_blank');
		});
		
		$('.akd-merlin-req-plugins').show();

		$(document).on('click', '.merlin__button--back', function (e){
			e.preventDefault();
			$('.csf-tabbed-active').prev().click();
		});

		$('.akd-demo-import').appendTo('.akd-demo-import-content');
		$('.akd-demo-import-content').hide();
		
		$(document).on('click', '.akd-close-import', function (e){
			e.preventDefault();
			window.location.href = window.location.href;
		});

		//update manual download link
		$(document).on('change', '#layout_select', function(e){
			$('.akd-download-manual-files').attr('href', $(this).val());
		})

		//hide install child theme button if already installed and activated
		if(akd_localization_data.theme_info.childTheme){
			$('.akd-install-child-theme').hide();
		}

		//add merlin class in the body
		$('body').addClass('merlin__body merlin__body--plugins sticky-menu loaded');

		//hide save button for the plugin and demo data screens
		$(document).on('click', '.csf-tabbed-nav', function(){
			if($(this).find('.csf-tabbed-active').text() === 'Plugins'){
				//hide save button as well
				$('.csf-save').hide();
			} else if($(this).find('.csf-tabbed-active').text() === 'Demo Data'){
				$('.csf-save').hide();
			} else {
				$('.csf-save').show();
			}
		});

		//hide theme setup from appearance
		// Find the li element containing "Theme Setup" text and hide it
		$("ul.wp-submenu li").filter(function() {
			return $(this).text() === "Theme Setup";
		}).hide();
	}

	//general tab content after theme activation
	function generalTabContentAfterActivation(){
		let content = `
			<div class="akd-theme-content akd-activated-theme-content">
				<div class="akd-cdf-description">
					<p>Consider installing a Child Theme now to protect your theme customizations from updates. We recommend this step for site stability. If you prefer to skip, click 'Start Setup' to proceed.</p>
				</div>`;
				if(akd_localization_data.theme_demo != '1'){
					
					content += `
						<div class="akd-cdf-buttons">							
							<a href="#" class="akd-install-child-theme akd-cdf-button">${akd_localization_data.theme_info.childThemeFound ? 'Activate Child Theme' : 'Create Child Theme'}</a>
							<a href="#" class="akd-cdf-next-step akd-cdf-button">Launch Setup</a>
							<div style="display:none; color:red" class="child-theme-loader">Loading...</div>
						</div>
					`;
				}
				
				content += `<div class="akd-license-section">
					<h2 class="akd-license-section-title">Hostiko license details</h2>
					<div class="akd-license-section-description">
						<p class="akd-license-section-info">Each theme license is valid for one domain. To switch the license to another domain, click 'Disconnect Domain' initially then proceed to enter the purchase code on a new WordPress site.</p>
						<p class="akd-license-section-note"><b>Important:</b> <b>For reinstallations on the same domain, disconnect the purchase code first.</p>
						<p class="akd-license-section-status">
							<span class="akd-license-section-status-title">Activation Status:</span>
							<span class="akd-license-section-status-label">Activated</span>
						</p>
						<p class="akd-license-domain">
							<span class="akd-license-domain-label">Domain:</span>
							<span class="akd-license-domain-url">${akd_localization_data.urls_to_frontend.siteUrl}</span>
						</p>
					</div>
					<div class="akd-license-btn">
						<a href="#" class="akd-cdf-button akd-disconnect-domain" data-purchase-code="${akd_localization_data.additional_data.purchaseCode ? akd_localization_data.additional_data.purchaseCode : ''}">Disconnect domain</a>
					</div>
				</div>
			</div>
			<div class="akd-server-info">
				<table class="akd-server-info-table">
					<tbody>
						<tr>
							<th>Server Configuration</th>
							<th>Current Configuration</th>
							<th>Suggested Configuration</th>
						</tr>
						<tr>
							<td data-tooltip-text="The version of WordPress installed on your site.">WordPress current version</td>
							<td style="${akd_localization_data.server_info.wp_version > '5.0' ? 'color:#38bb7a' : 'color:red'}">${akd_localization_data.server_info.wp_version}</td>
							<td>5.0+</td>
						</tr>
						<tr>
							<td data-tooltip-text="The version of PHP installed on your hosting server.">PHP version</td>
							<td style="${akd_localization_data.server_info.php_v > '7.0' ? 'color:#38bb7a' : 'color:red'}">${akd_localization_data.server_info.php_v}</td>
							<td>7.0+</td>
						</tr>
						<tr>
							<td data-tooltip-text="The directory must be writable to allow demo data upload, plugin and skin updates, etc.">WordPress writable permissions</td>
							<td style="color:#38bb7a">Yes</td>
							<td>Yes</td>
						</tr>
						<tr>
							<td data-tooltip-text="The maximum amount of memory (RAM) that your site can use at one time.">PHP Memory Limit</td>
							<td style="${akd_localization_data.server_info.php_memory_limit >= '128M' ? 'color:#38bb7a' : 'color:red'}">${akd_localization_data.server_info.php_memory_limit}</td>
							<td>128M</td>
						</tr>
						<tr>
							<td data-tooltip-text="The amount of time (in seconds) that your site will spend on a single operation before timing out (to avoid server lockups).">PHP Max Execution Time (sec)</td>
							<td style="${akd_localization_data.server_info.php_max_execution_time >= 300 ? 'color:#38bb7a' : 'color:red'}">${akd_localization_data.server_info.php_max_execution_time}</td>
							<td>300+</td>
						</tr>
					</tbody>
				</table>
			</div>

		`;

		return content;
	}

	//install child theme
	function installChildTheme(){
		$(document).on('click', '.akd-install-child-theme', function(e){
			e.preventDefault();
			$('.child-theme-loader').show();
			$.ajax({
				type: 'POST',
				url: akd_localization_data.urls_to_frontend.ajaxUrl,
				data: {
					action: 'install_child_theme',
					install: 'install_child',
				},
				success: function(response) {
					$('.child-theme-loader').hide();
					if(response.success === true && response.data != undefined){
						if(response.data.done === 1){
							$('.akd-cdf-buttons').after('<div class="validate-success"> '+response.data.message+' </div>');
							$('.akd-install-child-theme').hide();
						}
					}
				},
				error: function(error) {
					return error
				}
			});
		});
	}

	//download manual files
	function downloadThemeFiles(){
		$(document).on('click', '.akd-download-manual-files', function(e){
			e.preventDefault();
			let currentElement = $(this);
			$.ajax({
				type: 'POST',
				url: akd_localization_data.urls_to_frontend.ajaxUrl,
				data: {
					action: 'download_theme_files',
					layout: $(this).attr('href').split('layout-')[1],
				},
				success: function(response) {
					if(response && response.success === true && response.data != undefined){
						window.open(response.data, '_blank');
					} else if(response && response.success === false){
						$('.validate-error').remove();
						currentElement.parent().parent().parent().after('<div class="validate-error"> '+response.data.message+' </div>')
					}
				},
				error: function(error) {
					return error
				}
			});
		});
	}

	//download import files
	function downloadImportFiles(){
		$(document).on('click', '.akd-trigger-import', function(e){
			e.preventDefault();

			if (akd_localization_data.theme_info.requiredPlugins) {
				sessionStorage.setItem('activeTab', 'Install Demo');
				let content = `
					<div class="akd-wrapper">
						<div class="akd-loader-container">
						<div class="akd-loader"></div>
						</div>
					</div>
				`;
				$('.csf-options').append(content);

				let layoutNumber = $(this).data('layout');
				sessionStorage.setItem('layoutNumber', layoutNumber);

				$.ajax({
					type: 'POST',
					url: akd_localization_data.urls_to_frontend.ajaxUrl,
					data: {
						action: 'download_import_files',
						layout: layoutNumber,
					},
					success: function(response) {
						if(response && response.success === true && response.data != undefined){
							window.location.reload();
							// $('.akd-wrapper').remove();
						} else if(response && response.success === false && response.data != undefined){
							Swal.fire({
								title: "Oops!",
								text: response.data.message,
								icon: "error"
							});
							$('.akd-wrapper').remove();
						}
					},
					error: function(error) {
						return error
					}
				});

			} else {
				Swal.fire({
					title: "Oops!",
					text: "Install/Activate required plugins first.",
					icon: "error"
				});
			}
			
		});
	}

})( jQuery );
